/**
 *
 * Magnolia SimpleMedia Module (http://www.openmindlab.com/lab/products/media.html)
 * Copyright (C)2008 - 2010, Openmind S.r.l. http://www.openmindonline.it
 *
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * You may obtain a copy of the License at
 *
 * http://www.gnu.org/licenses/lgpl-2.1.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

package net.sourceforge.openutils.mgnlmedia.media.dialog;

import info.magnolia.cms.beans.runtime.Document;
import info.magnolia.cms.beans.runtime.MultipartForm;
import info.magnolia.cms.gui.dialog.DialogFile;
import info.magnolia.cms.gui.misc.Spacer;
import info.magnolia.cms.i18n.Messages;
import info.magnolia.cms.i18n.MessagesManager;
import info.magnolia.cms.i18n.MessagesUtil;

import java.io.IOException;
import java.io.Writer;

import org.apache.commons.lang.StringUtils;


/**
 * Overrides DialogFile and force no preview but the download link.<br/> Renders the list of valid file extensions
 * (specified by "extensions" property) and validates uploaded file against it.
 * @author molaschi
 * @version $Id: $
 */
public class DialogFileNoPreview extends DialogFile
{

    private final String i18nBasename = "net.sourceforge.openutils.mgnlmedia.media.lang.messages";

    private Messages messages;

    /**
     * {@inheritDoc}
     */
    @Override
    public void drawHtml(Writer out) throws IOException
    {
        this.getImageExtensions().clear();
        this.setConfig("preview", false);
        super.drawHtml(out);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public void drawHtmlPre(Writer out) throws IOException
    {
        super.drawHtmlPre(out);
        String extensions = this.getConfigValue("extensions");
        if (StringUtils.isNotBlank(extensions))
        {
            StringBuffer sb = new StringBuffer();
            sb
                .append("<span class=\"mgnlDialogDescription\">")
                .append(getMessage("dialog.filenopreview.extensions"))
                .append(" ")
                .append(extensions)
                .append("</span>")
                .append(Spacer.getHtml(0, 0));
            out.write(sb.toString());
        }
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public boolean validate()
    {
        boolean valid = super.validate();
        if (valid)
        {
            MultipartForm form = (MultipartForm) getRequest().getAttribute(MultipartForm.REQUEST_ATTRIBUTE_NAME);
            if (form != null)
            {
                Document doc = form.getDocument(getName());
                if (doc != null)
                {
                    String extensions = this.getConfigValue("extensions");
                    if (StringUtils.isNotBlank(extensions))
                    {
                        String[] allowedExtensions = StringUtils.split(extensions, ',');
                        for (String allowedExtension : allowedExtensions)
                        {
                            if (StringUtils.trimToEmpty(allowedExtension).equals(doc.getExtension()))
                            {
                                return true;
                            }

                        }

                        setValidationMessage(getMessage("dialog.filenopreview.error.extension"));
                        return false;
                    }
                }
                // String extensions = doc.getExtension();
            }
        }
        return valid;
    }

    @Override
    protected Messages getMessages()
    {
        if (messages == null)
        {
            // if this is the root
            if (this.getParent() == null)
            {
                messages = MessagesManager.getMessages();
            }
            else
            {
                // try to get it from the control nearest to the root
                messages = super.getMessages();
            }
            // if this control defines a bundle (basename in the terms of jstl)
            String basename = this.getConfigValue("i18nBasename", i18nBasename);
            if (StringUtils.isNotEmpty(basename))
            {
                // extend the chain with this bundle
                messages = MessagesUtil.chain(basename, messages);
            }
        }
        return messages;
    }

}
