/**
 *
 * Magnolia SimpleMedia Module (http://www.openmindlab.com/lab/products/media.html)
 * Copyright (C)2008 - 2010, Openmind S.r.l. http://www.openmindonline.it
 *
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * You may obtain a copy of the License at
 *
 * http://www.gnu.org/licenses/lgpl-2.1.html
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
 */

package net.sourceforge.openutils.mgnlmedia.media.types.impl;

import info.magnolia.cms.beans.runtime.MultipartForm;
import info.magnolia.cms.core.Content;

import java.io.File;
import java.net.MalformedURLException;
import java.net.URL;
import java.util.Map;
import java.util.UUID;

import javax.jcr.AccessDeniedException;
import javax.jcr.RepositoryException;
import javax.servlet.http.HttpServletRequest;

import org.apache.commons.lang.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;


/**
 * Type handler for youtube videos
 * @author molaschi
 * @version $Id: YouTubeVideoTypeHandler.java 1576 2009-12-31 15:29:37Z fgiust $
 */
public class YouTubeVideoTypeHandler extends MediaWithPreviewImageTypeHandler
{

    /**
     * Logger.
     */
    private final Logger log = LoggerFactory.getLogger(YouTubeVideoTypeHandler.class);

    /**
     * {@inheritDoc}
     */
    @Override
    public String getFilename(Content media)
    {
        return getUrl(media);
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getExtension(Content media)
    {
        return null;
    }

    @Override
    public void saveFromZipFile(Content media, File f, String cleanFileName, String extension)
        throws AccessDeniedException, RepositoryException
    {

    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getUrl(Content media, Map<String, String> options)
    {
        return media.getNodeData("videoUrl").getString();
    }

    /**
     * {@inheritDoc}
     */
    @Override
    public String getNewNodeName(MultipartForm form, HttpServletRequest request)
    {
        String videoUrl = request.getParameter("videoUrl");
        String id = UUID.randomUUID().toString();
        URL url;

        try
        {
            url = new URL(videoUrl);
            String query = url.getQuery();
            if (query != null)
            {
                for (String att : StringUtils.split(url.getQuery(), "&"))
                {
                    if (att.startsWith("v="))
                    {
                        id = StringUtils.substringAfter(att, "v=");
                    }
                }
            }
            else
            {
                id = StringUtils.substringAfterLast(videoUrl, "/");
            }
        }
        catch (MalformedURLException e)
        {
            log.error("Error parsing youtube url", e);
        }

        return id;
    }
}
